pub struct FsyncLatencyTracker { /* private fields */ }Expand description
Tracks fsync latency with exponential moving average for adaptive timeout calculation
Implementations
Sourceimpl FsyncLatencyTracker
impl FsyncLatencyTracker
Sourcepub fn record_success(&mut self, duration: Duration)
pub fn record_success(&mut self, duration: Duration)
Record a successful fsync and update the moving average
Sourcepub fn record_timeout(&mut self)
pub fn record_timeout(&mut self)
Record a timeout and double the average estimate
Sourcepub fn get_timeout(&self) -> Duration
pub fn get_timeout(&self) -> Duration
Calculate an adaptive timeout based on observed latency (avg + 4*deviation, clamped 5s..60s)